pub(crate) enum DivergingFallbackBehavior {
ToUnit,
ContextDependent,
ToNever,
}Variants
ToUnit
Always fallback to () (aka “always spontaneous decay”)
ContextDependent
Sometimes fallback to !, but mainly fallback to () so that most of the crates are not broken.
ToNever
Always fallback to ! (which should be equivalent to never falling back + not making
never-to-any coercions unless necessary)